@@ -78,7 +78,7 @@ static void pool_reset_memqcache_buffer(void);
 static POOL_CACHEID *pool_add_item_shmem_cache(POOL_QUERY_HASH *query_hash, char *data, int size);
 static POOL_CACHEID *pool_find_item_on_shmem_cache(POOL_QUERY_HASH *query_hash);
 static char *pool_get_item_shmem_cache(POOL_QUERY_HASH *query_hash, int *size, int *sts);
-static void pool_add_query_cache_array(POOL_QUERY_CACHE_ARRAY *cache_array, POOL_TEMP_QUERY_CACHE *cache);
+static POOL_QUERY_CACHE_ARRAY * pool_add_query_cache_array(POOL_QUERY_CACHE_ARRAY *cache_array, POOL_TEMP_QUERY_CACHE *cache);
 static void pool_add_temp_query_cache(POOL_TEMP_QUERY_CACHE *temp_cache, char kind, char *data, int data_len);
 static void pool_add_oids_temp_query_cache(POOL_TEMP_QUERY_CACHE *temp_cache, int num_oids, int *oids);
 static POOL_INTERNAL_BUFFER *pool_create_buffer(void);
@@ -746,7 +746,7 @@ bool pool_is_allow_to_cache(Node *node, char *query)
 			for (i = 0; i < num_oids; i++)
 			{
 				pool_debug("pool_is_allow_to_cache: check table_names[%d] = %s", i, ctx.table_names[i]);
-				if (pool_is_table_to_cache(ctx.table_names[i]) == false)
+				if (pool_is_table_in_black_list(ctx.table_names[i]) == true)
 				{
 					pool_debug("pool_is_allow_to_cache: false");
 					return false;
@@ -795,7 +795,7 @@ bool pool_is_allow_to_cache(Node *node, char *query)
 				pool_debug("pool_is_allow_to_cache: check table_names[%d] = %s", i, table);
 				if (is_view(table) || is_unlogged_table(table))
 				{
-					if (pool_is_table_to_cache(table) == false)
+					if (pool_is_table_in_white_list(table) == false)
 					{
 						pool_debug("pool_is_allow_to_cache: false");
 						return false;
@@ -821,32 +821,33 @@ bool pool_is_allow_to_cache(Node *node, char *query)
 	return true;
 }
 
+
 /*
- * Return true If the SELECTed table is in white list or is not in black list,
- * and table is to be cached.
+ * Return true If the SELECTed table is in back list.
  */
-bool pool_is_table_to_cache(const char *table_name)
+bool pool_is_table_in_black_list(const char *table_name)
 {
-	/* Cache in case of the table in white list */
-	if (pool_config->num_white_memqcache_table_list > 0)
+
+	if (pool_config->num_black_memqcache_table_list > 0 &&
+	    pattern_compare((char *)table_name, BLACKLIST, "black_memqcache_table_list") == 1)
 	{
-		if (pattern_compare((char *)table_name, WHITELIST, "white_memqcache_table_list") == 1)
-			return true;
-		else
-			return false;
+		return true;
 	}
 
-	/* No cache in case of the table in black list */
-	else if (pool_config->num_black_memqcache_table_list > 0)
+	return false;
+}
+
+/*
+ * Return true If the SELECTed table is in white list.
+ */
+bool pool_is_table_in_white_list(const char *table_name)
+{
+	if (pool_config->num_white_memqcache_table_list > 0 &&
+		pattern_compare((char *)table_name, WHITELIST, "white_memqcache_table_list") == 1)
 	{
-		if (pattern_compare((char *)table_name, BLACKLIST, "black_memqcache_table_list") == 1)
-			return false;
-		else
-			return true;
+		return true;
 	}
 
-	/* No cache otherwise */
-	pool_error("pool_is_table_to_cache: unknown case");
 	return false;
 }
 
@@ -2471,10 +2472,12 @@ static void dump_shmem_cache(POOL_CACHE_BLOCKID blockid)
 POOL_QUERY_CACHE_ARRAY *pool_create_query_cache_array(void)
 {
 #define POOL_QUERY_CACHE_ARRAY_ALLOCATE_NUM 128
+#define POOL_QUERY_CACHE_ARRAY_HEADER_SIZE (sizeof(int)+sizeof(int))
+
 	size_t size;
 	POOL_QUERY_CACHE_ARRAY *p;
 
-	size = sizeof(int) + sizeof(int) + POOL_QUERY_CACHE_ARRAY_ALLOCATE_NUM *
+	size = POOL_QUERY_CACHE_ARRAY_HEADER_SIZE + POOL_QUERY_CACHE_ARRAY_ALLOCATE_NUM *
 		sizeof(POOL_TEMP_QUERY_CACHE *);
 	p = malloc(size);
 	if (!p)
@@ -2507,26 +2510,28 @@ void pool_discard_query_cache_array(POOL_QUERY_CACHE_ARRAY *cache_array)
 /*
  * Add query cache array
  */
-static void pool_add_query_cache_array(POOL_QUERY_CACHE_ARRAY *cache_array, POOL_TEMP_QUERY_CACHE *cache)
+static POOL_QUERY_CACHE_ARRAY * pool_add_query_cache_array(POOL_QUERY_CACHE_ARRAY *cache_array, POOL_TEMP_QUERY_CACHE *cache)
 {
 	size_t size;
+	POOL_QUERY_CACHE_ARRAY *cp = cache_array;
 
 	if (!cache_array)
-		return;
+		return cp;
 
 	if (cache_array->num_caches >= 	cache_array->array_size)
 	{
 		cache_array->array_size += POOL_QUERY_CACHE_ARRAY_ALLOCATE_NUM;
-		size = cache_array->array_size + sizeof(int) + cache_array->array_size *
+		size = POOL_QUERY_CACHE_ARRAY_HEADER_SIZE + cache_array->array_size *
 			sizeof(POOL_TEMP_QUERY_CACHE *);
 		cache_array = realloc(cache_array, size);
 		if (!cache_array)
 		{
 			pool_error("pool_add_query_cache_array: malloc failed");
-			return;
+			return cp;
 		}
 	}
 	cache_array->caches[cache_array->num_caches++] = cache;
+	return cache_array;
 }
 
 /*
@@ -2934,7 +2939,8 @@ void pool_handle_query_cache(POOL_CONNECTION_POOL *backend, char *query, Node *n
 			 */
 			else
 			{
-				pool_add_query_cache_array(session_context->query_cache_array, cache);
+				session_context->query_cache_array = 
+					pool_add_query_cache_array(session_context->query_cache_array, cache);
 			}
 
 			/* Count up temporary SELECT stats */
