@@ -779,11 +779,13 @@ POOL_STATUS Execute(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend,
 		}
 	}
 
-	/*
-	 * Decide where to send query
-	 */
 	session_context->query_context = query_context;
-	pool_where_to_send(query_context, query, node);
+	/*
+	 * Calling pool_where_to_send here is dangerous because the node
+	 * parse/bind has been sent could be change by
+	 * pool_where_to_send() and it leads to "portal not found"
+	 * etc. errors.
+	 */
 
 	/* check if query is "COMMIT" or "ROLLBACK" */
 	commit = is_commit_or_rollback_query(node);
@@ -1275,11 +1277,12 @@ POOL_STATUS Bind(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend,
 	}
 
 	session_context->query_context = query_context;
-	pool_where_to_send(query_context, query_context->original_query,
-					   query_context->parse_tree);
 
 	if (pool_config->load_balance_mode && pool_is_writing_transaction())
 	{
+		pool_where_to_send(query_context, query_context->original_query,
+						   query_context->parse_tree);
+
 		if (parse_before_bind(frontend, backend, parse_msg) != POOL_CONTINUE)
 			return POOL_END;
 	}
@@ -1354,9 +1357,13 @@ POOL_STATUS Describe(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend,
 	}
 
 	session_context->query_context = query_context;
-	pool_where_to_send(query_context, query_context->original_query,
-					   query_context->parse_tree);
 
+	/*
+	 * Calling pool_where_to_send here is dangerous because the node
+	 * parse/bind has been sent could be change by
+	 * pool_where_to_send() and it leads to "portal not found"
+	 * etc. errors.
+	 */
 	pool_debug("Describe: waiting for master completing the query");
 	if (pool_extended_send_and_wait(query_context, "D", len, contents, 1, MASTER_NODE_ID)
 		!= POOL_CONTINUE)
@@ -1724,15 +1731,30 @@ POOL_STATUS ReadyForQuery(POOL_CONNECTION *frontend,
 						return POOL_END;
 				}
 
-				/*
-				 * If the query was not READ SELECT, and we are in an
-				 * explicit transaction, remember that we had a write
-				 * query in this transaction.
-				 */
-				else if (!is_select_query(node, query) &&
-						 TSTATE(backend, MASTER_SLAVE ? PRIMARY_NODE_ID : REAL_MASTER_NODE_ID) == 'T')
+				else if (!is_select_query(node, query))
 				{
-					pool_set_writing_transaction();
+					/*
+					 * If the query was not READ SELECT, and we are in an
+					 * explicit transaction, remember that we had a write
+					 * query in this transaction.
+					 */
+					if (TSTATE(backend, MASTER_SLAVE ? PRIMARY_NODE_ID : REAL_MASTER_NODE_ID) == 'T')
+					{
+						pool_set_writing_transaction();
+					}
+
+					/*
+					 * If the query was CREATE TEMP TABLE, discard
+					 * temp table relcache because we might have had
+					 * persistent table relation cache which has table
+					 * name as the tem table.
+					 */
+					if (IsA(node, CreateStmt))
+					{
+						CreateStmt *create_table_stmt = (CreateStmt *)node;
+						if (create_table_stmt->relation->istemp)
+							discard_temp_table_relcache();
+					}
 				}
 			}
 
