@@ -3,10 +3,10 @@
  *
  * Handles watchdog connection, and protocol communication with pgpool-II
  *
- * pgpool: a language independent connection pool server for PostgreSQL 
+ * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2012	PgPool Global Development Group
+ * Copyright (c) 2003-2013	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -93,7 +93,7 @@ wd_is_upper_ok(char * server_list)
 		}
 		if (cnt >= MAX_WATCHDOG_NUM)
 		{
-			pool_debug("wd_is_upper_ok: trusted server num is out of range(%d)",cnt);	
+			pool_debug("wd_is_upper_ok: trusted server num is out of range(%d)",cnt);
 			break;
 		}
 	}
@@ -111,7 +111,6 @@ wd_is_upper_ok(char * server_list)
 		{
 			rtn = WD_OK;
 		}
-		pthread_detach(thread[i]);
 		i++;
 	}
 	free(buf);
@@ -156,7 +155,6 @@ wd_is_unused_ip(char * ip)
 	{
 		rtn = WD_OK;
 	}
-	pthread_detach(thread);
 
 	return rtn;
 }
@@ -250,7 +248,7 @@ get_result (char * ping_data)
 	sp = ping_data;
 	for ( i = 0 ; i < 4 ; i ++)
 	{
-		sp = strchr(sp,'/');	
+		sp = strchr(sp,'/');
 		if (sp == NULL)
 		{
 			return -1;
